﻿//var i18nLang;
var i18nZh = {
    'insufficient privilege':'用户权限不在操作范围',
    'cannot pick own answer as best':'不能设置自己的回答为最佳答案',
    'anonymous users cannot select favorite questions':'匿名用户不能收藏问题，请先',
    'please login':'注册或者登录',
    'please see': '查看',
    'daily vote cap exhausted':'对不起，您已用完今日所有的投票。',
    'please confirm offensive':"确定要归类该帖为广告、人身攻击、恶意言论吗？",
    'anonymous users cannot flag offensive posts':'匿名用户不能操作，请先',
    'cannot flag message as offensive twice':'不能重复操作。',
    'flag offensive cap exhausted':'对不起，您已用完今日所有的5次‘水帖’操作。',
    'need >15 points to report spam':"需要+15积分才能归类‘垃圾帖’。",
    'confirm delete':"确定要删除/撤销删除该帖吗？",
    'anonymous users cannot delete/undelete':"匿名用户不能删除或撤销删除帖子",
    'post recovered':"操作成功！该帖子已被恢复。",
    'post deleted':"操作成功！该帖子已删除。",
    'add comment':'添加评论',
    'community karma points':'社区积分',
    'to comment, need':'评论需要',
    'delete this comment':'删除此评论',
    'hide comments':"隐藏评论",
    'add a comment':"添加评论",
    'comments':"评论",
    'confirm delete comment':"真要删除此评论吗？",
    'characters':'字符',
    'can write':'还可写',
    'click to close':'点击消息框关闭',
    'loading...':'读取中...',
    'tags cannot be empty':'标签不能为空。',
    'tablimits info':"最多5个标签，每个标签长度小于20个字符。",
    'content cannot be empty':'内容不能为空。',
    'content minchars': '请输入至少 {0} 字符。',
    'please enter title':'请输入标题。',
    'title minchars':"请输入至少 {0} 字符。",
    'delete':'删除',
    'undelete':	'取消',
    'bold':'粗体',
    'italic':'斜体',
    'link':'超链接',
    'quote':'引用',
    'preformatted text':'代码',
    'image':'图片',
    'numbered list':'数字编号列表',
    'bulleted list':'项目符号列表',
    'heading':'标题',
    'horizontal bar':'水平线',
    'undo':'撤销',
    'redo':'重做',
    'enter image url':'<b>输入图片地址</b></p><p>示例：<br />http://www.example.com/image.jpg   \"我的截图\"',
    'enter url':'<b>输入Web地址</b></p><p>示例：<br />http://www.cnprog.com/   \"我的网站\"</p>"',
    'upload image':'或者上传本地图片：'
};

var i18nZhtw = {
    'insufficient privilege':'權限不足',
    'cannot pick own answer as best':'不能蔽掃自珍',
    'anonymous users cannot select favorite questions':'匿名用戶不能收藏問題',
    'please login':'請先登錄',
    'please see': '查看',
    'daily vote cap exhausted':'對不起，您已用完今日所有的投票。',
    'please confirm offensive':"確定要歸類該帖為廣告、人身攻擊、惡意言論嗎？",
    'anonymous users cannot flag offensive posts':'匿名用戶不能操作',
    'cannot flag message as offensive twice':'不能重複操作。',
    'flag offensive cap exhausted':'對不起，您已用完今日所有的5次『水帖』操作。',
    'need >15 points to report spam':"需要 >15 積分才能歸類『垃圾帖』。",
    'confirm delete':"確定刪除",
    'anonymous users cannot delete/undelete':"匿名用戶不能刪除或恢復帖子",
    'post recovered':"操作成功！該帖子已被恢複。",
    'post deleted':"操作成功！該帖子已刪除。",
    'add comment':'添加評論',
    'community karma points':'社區積分',
    'to comment, need':'評論需要',
    'delete this comment':'刪除此評論',
    'hide comments':"隱藏評論",
    'add a comment':"添加評論",
    'comments':"評論",
    'confirm delete comment':"刪除評論確認",
    'characters':'字',
    'can write':'還可寫',
    'click to close':'點擊消息框關閉',
    'loading...':'讀取中...',
    'tags cannot be empty':'標籤不能為空白',
    'tablimits info':"最多5個標籤，每個標籤長度小於20個字符。",
    'content cannot be empty':'內容不能為空白',
    'content minchars': '請輸入至少 {0} 字符。',
    'please enter title':'請輸入標題。',
    'title minchars':"請輸入至少 {0} 字符。",
    'delete':'刪除',
    'undelete':	'取消',
    'bold':'粗體',
    'italic':'斜體',
    'link':'超連接',
    'quote':'引用',
    'preformatted text':'代碼',
    'image':'圖片',
    'numbered list':'數字編號列表',
    'bulleted list':'項目符號列表',
    'heading':'標題',
    'horizontal bar':'水平線',
    'undo':'撤銷',
    'redo':'重做',
    'enter image url':'<b>輸入圖片地址</b></p><p>示例：<br />http://www.example.com/image.jpg   \"我的截圖\"',
    'enter url':'<b>輸入Web地址</b></p><p>示例：<br />http://www.cnprog.com/   \"我的網站\"</p>"',
    'upload image':'或者上傳本地圖片：'
};


var i18nEn = {
    "anonymous users cannot vote": "sorry, anonymous users cannot vote ",
    'need >15 points to report spam':'need >15 points to report spam ',
    'tags cannot be empty':'please enter at least one tag',
    'anonymous users cannot select favorite questions':'sorry, anonymous users cannot select favorite questions ',
    'to comment, need': '(to comment other people\'s posts, karma ',
    'please see':'please see ',
    'community karma points':' or more is necessary) - ',
    'upload image':'Upload image:',
    'enter image url':'enter URL of the image, e.g. http://www.example.com/image.jpg \"image title\"',
    'enter url':'enter Web address, e.g. http://www.example.com \"page title\"',
    'daily vote cap exhausted':'sorry, you\'ve used up todays vote cap',
    'cannot pick own answer as best':'sorry, you cannot accept your own answer',
    'please confirm offensive':'are you sure this post is offensive, contains spam, advertising, malicious remarks, etc.?',
    'flag offensive cap exhausted':'sorry, you\'ve used up todays cap of flagging offensive messages ',
    'confirm delete':'are you sure you want to delete this?',
    'anonymous users cannot delete/undelete':'sorry, anonymous users cannot delete or undelete posts',
    'post recovered':'your post is now restored!',
    'post deleted':'your post has been deleted',
    'confirm delete comment':'do you really want to delete this comment?',
    'can write':'have ',
    'tablimits info':'up to 5 tags, no more than 20 characters each',
    'content minchars': 'please enter more than {0} characters',
    'title minchars':"please enter at least {0} characters",
    'characters':'characters left',
    'cannot flag message as offensive twice':'cannot flag message as offensive twice ',
};

var i18nFi = {
    "anonymous users cannot vote": "kirjaudu sisään, jotta voit käyttää tätä ominaisuutta ",
    'need >15 points to report spam':'tarvitset >15 pistettä raportoidaksesi roskapostista',
    'tags cannot be empty':'anna vähintään yksi tagi',
    'anonymous users cannot select favorite questions':'kirjaudu sisään, jotta voit käyttää tätä ominaisuutta',
    'to comment, need': '(kommentoidaksesi muita ',
    'please see':'katso ',
    'community karma points':' tai enemmän on vaadittu) - ',
    'upload image':'Lähetä kuva:',
    'enter image url':'Anna kuvan URL-osoite, esim. http://www.example.com/image.jpg \"kuvan otsikko\"',
    'enter url':'Anna URL-osoite, esim. http://www.example.com \"sivun otsikko\"',
    'daily vote cap exhausted':'olet käyttänyt tämän päivän osalta äänesi',
    'cannot pick own answer as best':'et voi hyväksyä omaa vastaustasi parhaaksi',
    'please confirm offensive':'oletko varma, että tämä on roskaposti, loukkaava tai muuta hyväksymätöntä?',
    'flag offensive cap exhausted':'olet käyttänyt tämän päivän merkkausmäärät ',
    'confirm delete':'oletko varma, että haluat poistaa tämän?',
    'anonymous users cannot delete/undelete':'kirjaudu sisään, jotta voit käyttää tätä ominaisuutta',
    'post recovered':'postauksesi on palautettu!',
    'post deleted':'postauksesi on poistettu',
    'confirm delete comment':'oletko varma, että haluat poistaa tämän kommentin?',
    'can write':'on ',
    'tablimits info':'maksimissaan 5 tagia, jotka ovat maksimissaan 20 merkkiä pitkiä',
    'content minchars': 'syötä vähintään {0} merkkiä',
    'title minchars':"syötä vähintään {0} merkkiä",
    'characters':'merkkiä jäljellä',
    'cannot flag message as offensive twice':'ei voi merkata kahta kertaa ',
    'questions/' : 'kysymykset/',
    'answers/' : 'vastukset/',
    'comments/' : 'kommentit/',
    'vote/' : 'aanesta/',
    'delete/' : 'poista/',
    //'unmark-tag/':'/',
    //'ignored/':'/',
    //'mark-tag/':'/',
    //'interesting/':'/',
    'command/':'komento/',
    'moderate-user/': 'muokkaa-kayttajaa/'
};

var i18nTr = {
    "anonymous users cannot vote":"üye girişi yapmadan oy kullanamazsınız",
    'insufficient privilege':'buna yetkiniz yoktur',
    'cannot pick own answer as best':'en cevap olarak kendi cevabınızı seçemezsiniz',
    'anonymous users cannot select favorite questions':'üye girişi yapmadan favori seçemezsiniz',
    'please login':'lütfen üye girişi yapınız',
    'please see': 'lütfen bakın',
    'daily vote cap exhausted':'bugünlük oy verme kotanız doldu',
    'please confirm offensive':"şikayetinizi onaylayın",
    'anonymous users cannot flag offensive posts':'üye girişi yapmadan şikayet gönderemezsiniz',
    'cannot flag message as offensive twice':'şikayet mesajı olarak iki kez işaretlemelisiniz',
    'flag offensive cap exhausted':'şikayet kotası aşıldı',
    'need >15 points to report spam':"spam olarak bildirmek için an az 15 puanınız olmalı",
    'confirm delete':"Bunu silmek istediğinizden emin misiniz?",
    'anonymous users cannot delete/undelete':"üye girişi yapmadan yazı silemez yada geri alamazsınız",
    'post recovered':"yazı geri alındı",
    'post deleted':"yazı silindi",
    'add comment':'yorum ekle',
    'community karma points':'site itibar puanları',
    'to comment, need':'Yorum için itibar puanınız olmalı',
    'delete this comment':'bu yorumu sil',
    'hide comments':"yorumları gizle",
    'add a comment':"yorum ekle",
    'comments':"yorumlar",
    'confirm delete comment':"yorumu silmek istediğinizden emin misiniz?",
    'characters':'karakter eksik',
    'can write':'yazılabilir ',
    'click to close':'kapatmak için tıklayın',
    'loading...':'yükleniyor...',
    'tags cannot be empty':'etiketler boş olamaz',
    'tablimits info':"En fazla 5 etiket ve her biri en fazla 20 karakter",
    'content cannot be empty':'içerik boş olamaz',
    'content minchars': 'Lütfen en az (0) karakter girin',
    'please enter title':'lütfen bir başlık yazın',
    'title minchars':"Lütfen en az (0) karakter girin",
    'delete':'sil',
    'undelete':	'geri al',
    'bold': 'kalın',
    'italic':'italik',
    'link':'link',
    'quote':'alıntı',
    'preformatted text':'hazır metin',
    'image':'resimler',
    'numbered list':'numaralı liste',
    'bulleted list':'işaretli liste',
    'heading':'Başlık',
    'horizontal bar':'yatay bar',
    'undo':'geri',
    'redo':'yeniden',
    'enter image url':'örnek resmin URLsini girin： <br />http://www.example.com/image.jpg   \"resim başlığı\"',
    'enter url':'web adresini girin： <br />http://www.cnprog.com/   \"başlık bağlantısı\"</p>"',
    'upload image':'resim yükle：',
    'questions/' : 'sorular/',
    'answers/' : 'cevaplar/',
    'comments/' : 'yorumlar/',
    'vote/' : 'oy/',
    'delete/' : 'sil/',
    'unmark-tag/':'etiket-işaretini-kaldır/',
    'ignored/':'yoksayıldı/',
    'mark-tag/':'etiket/',
    'interesting/':'ilginç/',
    'command/':'komut/',
    'moderate-user/': 'yöneticiler/'
};

var i18nEs = {
    "anonymous users cannot vote":"usuarios anónimos no pueden votar",
    'insufficient privilege':'privilegio insuficiente',
    'cannot pick own answer as best':'no puede escoger su propia respuesta como la mejor',
    'anonymous users cannot select favorite questions':'usuarios anonimos no pueden seleccionar',
    'please login':'por favor inicie sesión',
    'please see': 'por favor vea',
    'daily vote cap exhausted':'cuota de votos diarios excedida',
    'please confirm offensive':"por favor confirme ofensiva",
    'anonymous users cannot flag offensive posts':'usuarios anónimos no pueden marcar publicaciones como ofensivas',
    'cannot flag message as offensive twice':'no puede marcar mensaje como ofensivo dos veces',
    'flag offensive cap exhausted':'cuota para marcar ofensivas ha sido excedida',
    'need >15 points to report spam':"necesita >15 puntos para reportar spam",
    'confirm delete':"¿Está seguro que desea borrar esto?",
    'anonymous users cannot delete/undelete':"usuarios anónimos no pueden borrar o recuperar publicaciones",
    'post recovered':"publicación recuperada",
    'post deleted':"publicación borrada。",
    'add comment':'agregar comentario',
    'community karma points':'reputación comunitaria',
    'to comment, need':'para comentar, necesita reputación',
    'delete this comment':'borrar este comentario',
    'hide comments':"ocultar comentarios",
    'add a comment':"agregar comentarios",
    'comments':"comentarios",
    'confirm delete comment':"¿Realmente desea borrar este comentario?",
    'characters':'caracteres faltantes',
    'can write':'tiene ',
    'click to close':'haga click para cerrar',
    'loading...':'cargando...',
    'tags cannot be empty':'las etiquetas no pueden estar vacías',
    'tablimits info':"hasta 5 etiquetas de no mas de 20 caracteres cada una",
    'content cannot be empty':'el contenido no puede estar vacío',
    'content minchars': 'por favor introduzca mas de {0} caracteres',
    'please enter title':'por favor ingrese un título',
    'title minchars':"por favor introduzca al menos {0} caracteres",
    'delete':'borrar',
    'undelete':	'recuperar',
    'bold': 'negrita',
    'italic':'cursiva',
    'link':'enlace',
    'quote':'citar',
    'preformatted text':'texto preformateado',
    'image':'imagen',
    'numbered list':'lista numerada',
    'bulleted list':'lista no numerada',
    'heading':'标题',
    'horizontal bar':'barra horizontal',
    'undo':'deshacer',
    'redo':'rehacer',
    'enter image url':'introduzca la URL de la imagen, por ejemplo：<br />http://www.example.com/image.jpg   \"titulo de imagen\"',
    'enter url':'introduzca direcciones web, ejemplo：<br />http://www.cnprog.com/   \"titulo del enlace\"</p>"',
    'upload image':'cargar imagen：',
    'questions/' : 'preguntas/',
    'answers/' : 'respuestas/',
    'comments/' : 'comentarios/',
    'vote/' : 'votar/',
    'delete/' : 'eliminar/',
    'unmark-tag/':'desmarcar-etiqueta/',
    'ignored/':'ignorada/',
    'mark-tag/':'marcar-etiqueta/',
    'interesting/':'interesante/',
    'command/':'comando/',
    'moderate-user/': 'moderar-usuario/'
};

var i18nDe = {
    "anonymous users cannot vote":"Gastbenutzer können nicht abstimmen ",
    'add a comment': 'Kommentar hinzufügen', 
    'add comment': 'OK', 
    'anonymous users cannot delete/undelete': 'Gastbenutzer können Beiträge nicht löschen oder wiederherstellen', 
    'anonymous users cannot flag offensive posts': 'Gastbenutzer können Beiträge nicht melden', 
    'anonymous users cannot select favorite questions': 'Gastbenutzer können keine Fragen als Favoriten markieren', 
    'bold': 'Fett', 
    'bulleted list': 'Liste', 
    'can write': 'Noch ', 
    'cannot flag message as offensive twice': 'Beiträge können nicht doppelt gemeldet werden', 
    'cannot pick own answer as best': 'Eigene Antworten können nicht als die korrekte akzeptiert werden', 
    'characters': 'Zeichen', 
    'click to close': 'Schließen mit Klick', 
    'comments': 'Kommentare', 
    'community karma points': ' Punkte erforderlich) - ', 
    'confirm delete': 'Löschen bestätigen', 
    'confirm delete comment': 'Löschen des Kommentars bestätigen', 
    'content cannot be empty': 'Inhalt darf nicht leer sein', 
    'content minchars': 'Bitte mindestens {0} Zeichen eingeben', 
    'daily vote cap exhausted': 'Tägliches Abstimmungslimit erreicht', 
    'delete': 'löschen', 
    'delete this comment': 'Diesen Kommentar löschen', 
    'enter image url': 'Bild-URL eingeben, zum Beispiel <br />http://www.ihredomain.de/bildname.jpg', 
    'enter url': 'URL eingeben, zum Beispiel <br />http://www.askbot.org/ </p>', 
    'flag offensive cap exhausted': 'Tägliches Limit zum Melden von Beiträgen erreicht', 
    'heading': 'Titel', 
    'hide comments': 'Kommentare verstecken', 
    'horizontal bar': 'horizontaler Balken', 
    'image': 'Bild', 
    'insufficient privilege': 'nicht genügend Rechte', 
    'italic': 'Kursiv', 
    'link': 'Link', 
    'loading...': 'Lade...', 
    'need >15 points to report spam': 'Zum Melden von Spam werden mindestens 15 Punkte benötigt', 
    'numbered list': 'Nummerierte Liste', 
    'please confirm offensive': 'Bitte beleidigenden/regelwidrigen Beitrag bestätigen', 
    'please enter title': 'Bitte Titel eingeben', 
    'please login': 'Bitte einloggen', 
    'please see': 'Siehe', 
    'post deleted': 'Beitrag gelöscht', 
    'post recovered': 'Beitrag wiederhergestellt', 
    'preformatted text': 'Vorformatierter Text', 
    'quote': 'Zitat', 
    'redo': 'Wiederholen', 
    'tablimits info': 'Bis zu 5 Tags mit jeweils bis zu 20 Zeichen', 
    'tags cannot be empty': 'Tags dürfen nicht leer sein', 
    'title minchars': 'Bitte mindestens {0} Zeichen eingeben', 
    'to comment, need': '(Um Beiträge anderer benutzer zu kommentieren, sind mindestens ', 
    'undelete': 'wiederherstellen', 
    'undo': 'Rückgängig', 
    'upload image': 'Bild hochladen', 
    'questions/': 'fragen/', 
    'question/': 'frage/',
    'delete/': 'loeschen/', 
    'comments/': 'kommentare/', 
    'answers/': 'antworten/', 
    'vote/': 'abstimmen/',
    'unmark-tag/':'tag-entfernen/',
    'ignored/':'ignoriert/',
    'mark-tag/':'tag-markieren/',
    'interesting/':'interessant/',
    'command/':'befehl/',
    'moderate-user/': 'benutzer-moderieren/',
    'account/': 'zugang/',
    'signin/': 'einloggen/'
};


var i18nRu = {
    "anonymous users cannot vote": "неавторизированные пользователи не могут голосовать ",
    'add a comment': 'добавить комментарий', 
    'add comment': 'добавить комментарий', 
    'anonymous users cannot delete/undelete': 'неавторизированные пользователи не могут восстанавливать и удалять сообщения', 
    'anonymous users cannot flag offensive posts': 'неавторизированные пользователи не могут пожаловаться на сообщение', 
    'anonymous users cannot select favorite questions': 'неавторизированные пользователи не могут добавлять вопросы в закладки', 
    'answers/': 'ответы/', 
    'bold': 'жирный', 
    'bulleted list': 'список', 
    'can write': 'пишите', 
    'cannot flag message as offensive twice': 'нельзя отметить сообщение как спам два раза', 
    'cannot pick own answer as best': 'нельзя выбрать собственный ответ в качестве лучшего',
    'characters': 'символы', 
    'click to close': 'нажмите, что бы закрыть', 
    'comments': 'комментарии', 
    'comments/': 'комментарии/', 
    'community karma points': 'репутация сообщества', 
    'confirm delete': 'подтвердите удаление', 
    'confirm delete comment': 'удалить комментарий', 
    'content cannot be empty': 'поле не может быть пустым', 
    'content minchars': 'не допускается пустое содержание', 
    'daily vote cap exhausted': 'исчерпан доступный на сегодня лимит голосований', 
    'delete': 'удалить', 
    'delete this comment': 'удалить комментарий', 
    'delete/': 'удалить/', 
    'enter image url': 'введите url изображения, например:<br /> http://www.domain.ru/kartinka.gif', 
    'enter url': 'введите url, например:<br />http://www.domain.ru/ </p>', 
    'flag offensive cap exhausted': 'исчерпан доступный на сегодня лимит сообщений о спаме', 
    'heading': 'заголовок', 
    'hide comments': 'скрыть комментарий', 
    'horizontal bar': 'горизонтальная полоса', 
    'image': 'изображение', 
    'insufficient privilege': 'недостаточно прав', 
    'italic': 'курсив', 
    'link': 'ссылка', 
    'loading...': 'загрузка...', 
    'need >15 points to report spam': 'Сообщать о спеме могут пользователи с количеством баллов не меньше 15', 
    'numbered list': 'нумерация', 
    'please confirm offensive': 'сообщить о спаме', 
    'please enter title': 'пожалуйста, введите заголовок', 
    'please login': 'введите логин', 
    'please see': 'смотрите', 
    'post deleted': 'сообщение удалено', 
    'post recovered': 'восстановить сообщение', 
    'preformatted text': 'форматирование текста', 
    'questions/': 'вопросы/', 
    'quote': 'цитата', 
    'redo': 'повторить', 
    'tablimits info': 'допускается применение не более 5 тегов', 
    'tags cannot be empty': 'введите теги', 
    'title minchars': 'пустой заголовок', 
    'to comment, need': '(необходимо оставить комментарий ', 
    'undelete': 'восстановить', 
    'undo': 'отменить', 
    'upload image': 'загрузить изображение', 
    'vote/': 'голосовать/',
    'unmark-tag/':'отменить-отметку-темы/',
    'ignored/':'неинтересная/',
    'mark-tag/':'отметить-тему/',
    'interesting/':'интересная/',
    'command/':'комманда/',
    'moderate-user/': 'модерировать-пользователя/'
};

var i18nFr = {
    "anonymous users cannot vote":"les utilisateurs anonyment ne peuvent pas voter ",
    'add a comment': 'Ajouter un commentaire', 
    'add comment': 'OK', 
    'anonymous users cannot delete/undelete': 'Les utilisateurs anonymes ne peuvent pas supprimer/restaurer', 
    'anonymous users cannot flag offensive posts': 'Les utilisateurs anonymes ne peuvent pas signaler les messages à contenu abusif', 
    'anonymous users cannot select favorite questions': 'Les utilisateurs anonymes ne peuvent pas sélectionner leurs questions favorites', 
    'bold': 'gras', 
    'bulleted list': 'liste', 
    'can write': 'peut écrire ', 
    'cannot flag message as offensive twice': 'Vous ne pouvez pas signaler deux fois un message à contenu abusif', 
    'cannot pick own answer as best': 'Vous ne pouvez pas désigner une de vos propres réponses comme étant la meilleure réponse', 
    'characters': 'caractères', 
    'click to close': 'cliquez pour fermer', 
    'comments': 'commentaires', 
    'community karma points': ' Points de karma - ', 
    'confirm delete': 'Confirmer la suppression', 
    'confirm delete comment': 'Confirmer la suppression du commentaire', 
    'content cannot be empty': 'Le contenu ne doit pas être vide', 
    'content minchars': 'Veuillez saisir au moins {0} caractères', 
    'daily vote cap exhausted': 'Votre quota journalier de votes est atteint', 
    'delete': 'supprimer', 
    'delete this comment': 'supprimer ce commentaire', 
    'enter image url': 'Veuillez saisir une URL menant à une image, par exemple <br />http://www.votre-domaine.com/nom-image.jpg', 
    'enter url': 'Entrez une URL, par exemple <br />http://www.askbot.org/ </p>', 
    'flag offensive cap exhausted': 'Votre quota journalier de signalements de contenus abusifs a été atteint', 
    'heading': 'Titre', 
    'hide comments': 'Masquer les commentaires', 
    'horizontal bar': 'Barre horizontale', 
    'image': 'Image', 
    'insufficient privilege': 'Privilèges insuffisants', 
    'italic': 'italique', 
    'link': 'lien', 
    'loading...': 'Chargement en cours...', 
    'need >15 points to report spam': 'Vous devez avoir au moins 15 points de réputation pour signaler du spam', 
    'numbered list': 'liste numérotée', 
    'please confirm offensive': 'Veuillez confirmer que le contenu est abusif', 
    'please enter title': 'Veuillez saisir un titre', 
    'please login': 'Veuillez vous authentifier', 
    'please see': 'Pour en savoir plus', 
    'post deleted': 'Message supprimé', 
    'post recovered': 'Message restauré', 
    'preformatted text': 'Texte préformaté', 
    'quote': 'Citer', 
    'redo': 'Rétablir', 
    "tablimits info": "Jusqu'à cinq mots-clés (tags), chacun comportant jusqu'à 20 caractères", 
    'tags cannot be empty': 'Les mots-clés ne doivent pas être vides', 
    'title minchars': 'Veuillez saisir au moins {0} caractères', 
    "to comment, need": "Pour faire des commentaires sur les commentaires d'autres utilisateurs, vous devez avoir au moins ", 
    'undelete': 'Restaurer', 
    'undo': 'Annuler', 
    'upload image': 'Charger une image', 
    'questions/': 'questions/', 
    'question/': 'question/',
    'delete/': 'supprimer/', 
    'comments/': 'commentaires/', 
    'answers/': 'reponses/', 
    'vote/': 'voter/',
    'unmark-tag/':'retirer-un-tag/',
    'ignored/':'ignoree/',
    'mark-tag/':'marquer-avec-un-tag/',
    'interesting/':'interessant/',
    'command/':'commande/',
    'moderate-user/': 'moderer-utilisateur/',
    'account/': 'compte/',
    'signin/': 'connexion/'
};

var i18n = {
    'en':i18nEn,
    'zh-cn':i18nZh,
    'es':i18nEs,
    'tr':i18nTr,
    'de':i18nDe,
    'ru':i18nRu,
    'fr':i18nFr,
    'zh-tw':i18nZhtw
};

var i18n_dict = i18n[i18nLang];

